pub struct PatternDefinition { /* private fields */ }Expand description
Represents the object managing all the symbols used in pattern definitions
Implementations
Sourceimpl PatternDefinition
impl PatternDefinition
Sourcepub fn new() -> PatternDefinition
pub fn new() -> PatternDefinition
Constructs a new PatternDefinition
Example
extern crate test_data_generation;
use test_data_generation::engine::PatternDefinition;
fn main() {
let pttrn_def = PatternDefinition::new();
}Sourcepub fn analyze(&mut self, entity: &str) -> (String, Vec<Fact>)
pub fn analyze(&mut self, entity: &str) -> (String, Vec<Fact>)
This function converts an entity (&str) into a tuplet (String, Vec
Arguments
entity: String- The textual str of the value to analyze.
Example
extern crate test_data_generation;
use test_data_generation::engine::PatternDefinition;
fn main() {
let mut pttrn_def = PatternDefinition::new();
//async {
let rslt = pttrn_def.analyze("Hello World");
assert_eq!(rslt.0, "CvccvSCvccc");
//}
}Sourcepub fn factualize(&mut self, entity: &str, idx: u32) -> Fact
pub fn factualize(&mut self, entity: &str, idx: u32) -> Fact
This function converts a char in an entity (&str) based on the index specified into a Fact
Arguments
entity: String- The textual str of the value to analyze.idx: u32- The index that specifies the position of the char in the entity to convert to a Fact.
Example
extern crate test_data_generation;
use test_data_generation::engine::PatternDefinition;
fn main() {
let mut pttrn_def = PatternDefinition::new();
let fact = pttrn_def.factualize("Word",0);
// will return a Fact that represents the char `W`
}Sourcepub fn get(&self, key: &str) -> char
pub fn get(&self, key: &str) -> char
This function returns a pattern symbol that represents the type of character
Example
extern crate test_data_generation;
use test_data_generation::engine::PatternDefinition;
fn main() {
let pttrn_def = PatternDefinition::new();
println!("Upper case vowel symbol: {:?}", pttrn_def.get(&"VowelUpper".to_string()));
}Sourcepub fn symbolize_char(&self, c: char) -> char
pub fn symbolize_char(&self, c: char) -> char
This function converts a char into a pattern symbol
Example
extern crate test_data_generation;
use test_data_generation::engine::PatternDefinition;
fn main() {
let pttrn_def = PatternDefinition::new();
println!("The pattern symbol for 'A' is {:?}", pttrn_def.symbolize_char('A'));
// The pattern symbol for 'A' is V
}Auto Trait Implementations
impl Freeze for PatternDefinition
impl RefUnwindSafe for PatternDefinition
impl Send for PatternDefinition
impl Sync for PatternDefinition
impl Unpin for PatternDefinition
impl UnsafeUnpin for PatternDefinition
impl UnwindSafe for PatternDefinition