Struct test_data_generation::engine::PatternDefinition[][src]

pub struct PatternDefinition { /* fields omitted */ }
Represents the object managing all the symbols used in pattern definitions

Implementations

Constructs a new PatternDefinition

Example
extern crate test_data_generation;

use test_data_generation::engine::PatternDefinition;

fn main() {
	let pttrn_def = PatternDefinition::new();
}

This function converts an entity (&str) into a tuplet (String, Vec)

Arguments
  • entity: String - The textual str of the value to anaylze.
Example
extern crate test_data_generation;

use test_data_generation::engine::PatternDefinition;

fn main() {
	let mut pttrn_def = PatternDefinition::new();
    //async {
        let rslt = pttrn_def.analyze("Hello World");
        assert_eq!(rslt.0, "CvccvSCvccc");
    //}
}

This function converts a char in an entity (&str) based on the index specified into a Fact

Arguments
  • entity: String - The textual str of the value to anaylze.
  • idx: u32 - The index that specifies the position of the char in the entity to convert to a Fact.
Example
extern crate test_data_generation;

use test_data_generation::engine::PatternDefinition;

fn main() {
	let mut pttrn_def = PatternDefinition::new();
	let fact = pttrn_def.factualize("Word",0);
    // will return a Fact that represents the char `W`
}

This function returns a pattern symbol that represents the type of character

Example
extern crate test_data_generation;

use test_data_generation::engine::PatternDefinition;

fn main() {
	let pttrn_def = PatternDefinition::new();
    println!("Upper case vowel symbol: {:?}", pttrn_def.get(&"VowelUpper".to_string()));
}

This function converts a char into a pattern symbol

Example
extern crate test_data_generation;

use test_data_generation::engine::PatternDefinition;

fn main() {
	let pttrn_def = PatternDefinition::new();
	println!("The pattern symbol for 'A' is {:?}", pttrn_def.symbolize_char('A'));
    // The pattern symbol for 'A' is V
}